@@ -14,6 +14,8 @@ from deskbar.DeskbarAppletPreferences import DeskbarAppletPreferences
 from deskbar.Keybinder import get_deskbar_keybinder
 from deskbar.ui.cuemiac.Cuemiac import CuemiacUI
 from deskbar.ui.completion.CompletionDeskbarUI import CompletionDeskbarUI
+from deskbar.ui.entriac.CuemiacEntryUI import CuemiacEntryUI
+
 
 class DeskbarApplet:
 	def __init__(self, applet):
@@ -42,7 +44,7 @@ class DeskbarApplet:
 		# Set and retrieve the UI to be used
 		ui_name = deskbar.GCONF_CLIENT.get_string(self.prefs.GCONF_UI_NAME)
 		if ui_name == None:
-			ui_name = deskbar.COMPLETION_UI_NAME
+			ui_name = deskbar.ENTRIAC_UI_NAME
 		
 		# Watch out for UI override from command line
 		if deskbar.UI_OVERRIDE != None:
@@ -51,11 +53,13 @@ class DeskbarApplet:
 		# Check for cairo otherwise cuemiac isn't available at all
 		if not hasattr(gtk.gdk.Drawable, 'cairo_create'):
 			ui_name = deskbar.COMPLETION_UI_NAME
-			
+		
 		if ui_name == deskbar.COMPLETION_UI_NAME:
 			self.ui = CompletionDeskbarUI (applet, self.prefs)
 		elif ui_name == deskbar.CUEMIAC_UI_NAME:
 			self.ui = CuemiacUI (applet, self.prefs)
+		elif ui_name == deskbar.ENTRIAC_UI_NAME:
+			self.ui = CuemiacEntryUI(applet, self.prefs)
 			
 		# Set up the chosen UI
 		self.set_up_ui_signals ()
@@ -105,11 +109,11 @@ class DeskbarApplet:
 				modctx.module.query_async(qstring, MAX_RESULTS_PER_HANDLER)
 			else:
 				matches = modctx.module.query(qstring, MAX_RESULTS_PER_HANDLER)
-				for match in matches: # FIXME: This can be optimised
+				for match in matches:
 					text, match = qstring, match
 					if type(match) is tuple:
 						text, match = match
-					
+
 					hsh = match.get_hash(text)
 					if hsh != None:
 						if hsh in self._match_hashes:
@@ -119,7 +123,7 @@ class DeskbarApplet:
 						results.append((text,match))
 					else:
 						results.append((text,match))
-				
+
 		self.ui.append_matches (results)
 	
 	def dispatch_matches (self, matches):
@@ -276,7 +280,8 @@ class DeskbarApplet:
 			
 		if ui_name == deskbar.CUEMIAC_UI_NAME:
 			self.ui = CuemiacUI (self.applet, self.prefs)
-			
+		elif ui_name == deskbar.ENTRIAC_UI_NAME:
+			self.ui = CuemiacEntryUI(self.applet, self.prefs)
 		elif ui_name == deskbar.COMPLETION_UI_NAME:
 			self.ui = CompletionDeskbarUI (self.applet, self.prefs)
 		
