@@ -59,7 +59,8 @@ os.chdir(expanduser("~"))
 # Path to images, icons
 ART_DATA_DIR = join(SHARED_DATA_DIR, "art")
 # Default icon size in the entry
-ICON_SIZE = 16
+ICON_WIDTH = 28
+ICON_HEIGHT = 16
 
 #Maximum number of history items
 MAX_HISTORY = 25
@@ -86,6 +87,7 @@ GCONF_KEYBINDING = GCONF_DIR + "/keybinding"
 GCONF_UI_NAME = GCONF_DIR + "/ui_name"
 
 COMPLETION_UI_NAME = "Completion"
+ENTRIAC_UI_NAME = "Entriac"
 CUEMIAC_UI_NAME = "Cuemiac"
 
 # GConf key for list of enabled handlers, when uninstalled, use a debug key to not conflict
