@@ -1,5 +1,5 @@
 DATA_DIR = "/usr/share"
 LIB_DIR = "/usr/lib"
-VERSION = "2.13.90"
+VERSION = "2.13.91"
 PACKAGE = "deskbar-applet"
-PYTHONPATH = "/usr/lib/python2.4/site-packages"
+PYTHONDIR = "/usr/lib/python2.4/site-packages"
