@@ -23,12 +23,19 @@ if _check(name):
 	print 'Running uninstalled deskbar, modifying PYTHONPATH'
 	sys.path.insert(0, abspath(name))
 else:
-	sys.path.insert(0, abspath("@PYTHONPATH@"))
-	print "Running installed deskbar, using [@PYTHONPATH@:$PYTHONPATH]"
+	sys.path.insert(0, abspath("@PYTHONDIR@"))
+	print "Running installed deskbar, using [@PYTHONDIR@:$PYTHONPATH]"
 
 # Now the path is set, import our applet
 import deskbar, deskbar.DeskbarApplet, deskbar.defs
 
+try:
+	# attempt to set a name for killall
+	import deskbar.osutils
+	deskbar.osutils.set_process_name ("deskbar-applet")
+except:
+	print "Unable to set processName"
+
 import gettext, locale
 gettext.bindtextdomain('deskbar-applet', abspath(join(deskbar.defs.DATA_DIR, "locale")))
 gettext.textdomain('deskbar-applet')
@@ -95,7 +102,7 @@ if __name__ == "__main__":
 		if cuemiac:
 			deskbar.UI_OVERRIDE = deskbar.CUEMIAC_UI_NAME
 		else:
-			deskbar.UI_OVERRIDE = deskbar.COMPLETION_UI_NAME
+			deskbar.UI_OVERRIDE = deskbar.ENTRIAC_UI_NAME
 
 		import gnome
 		gnome.init(deskbar.defs.PACKAGE, deskbar.defs.VERSION)
