@@ -45,7 +45,7 @@ TYPES = {
 		"name"	: ("fixme:FileAs",),
 		"action": "evolution %(uri)s",
 		"icon"	: "stock_contact",
-		"description": _("Addressbook entry for %s") % "<b>%(name)s</b>",
+		"description": _("Send Email to %s") % "<b>%(name)s</b>",
 		"category": "people",
 		},
 	
@@ -55,7 +55,7 @@ TYPES = {
 		"icon"	: "stock_mail",
 		"extra": {"sender":("fixme:from_name", "parent:fixme:from_name")},
 		#translators: First %s is mail sender, second %s is mail subject.
-		"description": _("View email from <i>%(sender)s</i>: <b>%(name)s</b>"),
+		"description": (_("Email from %s") % "<i>%(sender)s</i>" ) + "\n<b>%(name)s</b>",
 		"category": "documents",
 		},
 	"File" 		: {
@@ -69,18 +69,18 @@ TYPES = {
 		},
 	"FeedItem"	: {
 		"name"	: ("dc:title",),
-		"extra" : {"identifier": ("dc:identifier",)},
 		"action": "gnome-open %(identifier)s",
 		"icon"	: "stock_news",
-		"description": _("Open news item %s") % "<b>%(name)s</b>",
+		"description": (_("News from %s") % "<i>%(publisher)s</i>" ) + "\n<b>%(name)s</b>",
 		"snippet": True,
 		"category": "web",
+		"extra": {"publisher":("dc:publisher",), "identifier": ("dc:identifier",)},
 		},
 	"Note"		: {
 		"name"	: ("dc:title",),
 		"action": "tomboy --open-note %(uri)s",
 		"icon"	:"stock_notes",
-		"description": _("Open note %s") % "<b>%(name)s</b>",
+		"description": _("Note: %s") % "<b>%(name)s</b>",
 		"snippet": True,
 		"category": "documents",
 		},
@@ -88,7 +88,7 @@ TYPES = {
 		"name"	: ("fixme:speakingto",),
 		"action": "beagle-imlogviewer %(uri)s",
 		"icon"	: "im",
-		"description": _("View conversation with %s") % "<b>%(name)s</b>",
+		"description": _("Conversation with %s") % "<b>%(name)s</b>",
 		"snippet": True,
 		"category": "documents",
 		},
@@ -96,15 +96,14 @@ TYPES = {
 		"name"	: ("fixme:summary",),
 		"action": "evolution %(uri)s",
 		"icon"	: "stock_calendar",
-		"description": _("View calendar %s") % "<b>%(name)s</b>",
+		"description": _("Calendar: %s") % "<b>%(name)s</b>",
 		"category": "documents",
 		},
 	"WebHistory": {
-		"name"	: ("dc:title",),
+		"name"	: ("dc:title",), # FIX-BEAGLE bug #330053, dc:title returns as None even though it _is_ set
 		"action": "gnome-open %(uri)s",
 		"icon"	: "stock_bookmark",
-		"description": _("Open History Item %s") % "<b>%(name)s</b>",
-		"snippet": True,
+		"description": (_("Open History Item %s") % "<i>%(name)s</i>") + "\n%(uri)s",
 		"category": "web",
 		},
 }
@@ -250,40 +249,45 @@ class BeagleLiveHandler(deskbar.Handler.SignallingHandler):
 			result["snippet"] = "\n<span foreground='grey' size='small'>%s</span>" % cgi.escape(tmp)
 		else:
 			result["snippet"] = ""
-			
+		
+		name = None
 		for prop in hit_type["name"]:
 			try:
-				name = hit.get_one_property(prop)
+				name = hit.get_properties(prop)[0] # get_property_one() would be cleaner, but this works around bug #330053
 			except:
 				try:
 					# Beagle < 0.2
 					name = hit.get_property(prop)
 				except:
-					continue
+					pass
 					
 			if name != None:
 				result["name"] = cgi.escape(name)
 				break
-		else:
+		
+		if name == None:
 			#translators: This is used for unknown values returned by beagle
 			#translators: for example unknown email sender, or unknown note title
 			result["name"] = _("?")
 			
 		if "extra" in hit_type:
 			for prop, keys in hit_type["extra"].items():
+				val = None
 				for key in keys:
 					try:
-						val = hit.get_one_property(key)
+						val = hit.get_properties(key)[0] # get_property_one() would be cleaner, but this works around bug #330053
 					except:
 						try:
 							# Beagle < 0.2
 							val = hit.get_property(key)
 						except:
-							continue
+							pass
+							
 					if val != None:
 						result[prop] = cgi.escape(val)
 						break
-				else:
+					
+				if val == None:
 					#translators: This is used for unknown values returned by beagle
 					#translators: for example unknown email sender, or unknown note title
 					result[prop] = _("?")
