@@ -1,7 +1,7 @@
 from gettext import gettext as _
 
 import gnomevfs
-import deskbar.handler
+import deskbar.Handler
 import re
 
 HANDLERS = {
@@ -13,28 +13,29 @@ HANDLERS = {
 
 REGEX = re.compile(r'^([\w\-]+\.)*[\w\-]+@([\w\-]+\.)*[\w\-]+$')
 
-class EmailAddressMatch(deskbar.handler.Match):
-	def __init__(self, backend, email):
-		deskbar.handler.Match.__init__(self, backend, email)
-		
-		self._email = email
+class EmailAddressMatch(deskbar.Match.Match):
+	def __init__(self, backend, **args):
+		deskbar.Match.Match.__init__(self, backend, **args)
 		
 	def action(self, text=None):
-		gnomevfs.url_show("mailto:"+self._email)
+		gnomevfs.url_show("mailto:"+self.name)
+		
+	def get_category(self):
+		return "people"
 	
 	def get_verb(self):
 		return _("Send Email to %s") % "<b>%(name)s</b>"
 	
 	def get_hash(self, text=None):
-		return self._email
+		return self.name
 		
 	
-class EmailAddressHandler(deskbar.handler.Handler):
+class EmailAddressHandler(deskbar.Handler.Handler):
 	def __init__(self):
-		deskbar.handler.Handler.__init__(self, "stock_mail")
+		deskbar.Handler.Handler.__init__(self, "stock_mail")
 		
-	def query(self, query, max=5):
+	def query(self, query, max):
 		if REGEX.match(query) != None:
-			return [EmailAddressMatch(self, query)]
+			return [EmailAddressMatch(self, name=query)]
 		else:
 			return []
