@@ -5,9 +5,9 @@ from gettext import gettext as _
 
 import gobject
 import gtk
-import deskbar, deskbar.indexer, deskbar.locale_utils, deskbar.handler_utils
-import deskbar.handler, deskbar.gnomedesktop
-from deskbar.handler_utils import get_xdg_data_dirs
+import deskbar, deskbar.Indexer, deskbar.Utils
+import deskbar.Handler, deskbar.gnomedesktop
+from deskbar.Utils import get_xdg_data_dirs
 
 HANDLERS = {
 	"ProgramsHandler" : {
@@ -24,15 +24,20 @@ HANDLERS = {
 	},
 }
 
-class GenericProgramMatch(deskbar.handler.Match):
-	def __init__(self, backend, desktop, use_arg=False):
-		self._name = cgi.escape(desktop.get_localestring(deskbar.gnomedesktop.KEY_NAME))
-		icon = deskbar.handler_utils.load_icon_for_desktop_icon(desktop.get_string(deskbar.gnomedesktop.KEY_ICON))
+class GenericProgramMatch(deskbar.Match.Match):
+	def __init__(self, backend, use_arg=False, desktop=None, desktop_file=None, **args):
+		deskbar.Match.Match.__init__(self, backend, **args)
 		
-		deskbar.handler.Match.__init__(self, backend, self._name, icon)
+		self.desktop_file = desktop_file
+		self.use_arg = use_arg
 		
+		self._icon = deskbar.Utils.load_icon_for_desktop_icon(self.icon)
 		self._desktop = desktop
-		self._use_arg = use_arg
+		if desktop == None:
+			self._desktop = parse_desktop_filename(desktop_file)
+			if self._desktop == None:
+				raise Exception("Desktop file not found, ignoring")
+		
 		# Strip %U or whatever arguments in Exec field
 		exe = re.sub("%\w+", "", self._desktop.get_string("Exec"))
 		# Strip any absolute path like /usr/bin/something to display only something
@@ -46,7 +51,7 @@ class GenericProgramMatch(deskbar.handler.Match):
 		return self._display_prog
 		
 	def action(self, text=None):
-		if self._use_arg and text != None:
+		if self.use_arg and text != None:
 			args = [self._desktop.get_string("Exec")]
 			if hasattr(self, "_args"):
 				args = args + self._args
@@ -58,6 +63,9 @@ class GenericProgramMatch(deskbar.handler.Match):
 		else:
 			self._desktop.launch([])
 	
+	def get_category(self):
+		return "actions"
+	
 	def get_verb(self):
 		#translators: First %s is the programs full name, second is the executable name
 		#translators: For example: Launch Text Editor (gedit)
@@ -65,40 +73,41 @@ class GenericProgramMatch(deskbar.handler.Match):
 		
 	def get_name(self, text=None):
 		return {
-			"name": self._name,
+			"name": self.name,
 			"prog": self._display_prog,
 		}
 		
 class GnomeDictMatch(GenericProgramMatch):
-	def __init__(self, backend, desktop):
-		GenericProgramMatch.__init__(self, backend, desktop, True)
+	def __init__(self, backend, use_arg=True, **args):
+		GenericProgramMatch.__init__(self, backend, use_arg=use_arg, **args)
+		self._args = ["--look-up"]
 	
 	def get_verb(self):
 		return _("Lookup %s in dictionary") % "<b>%(text)s</b>"
 
 class GnomeSearchMatch(GenericProgramMatch):
-	def __init__(self, backend, desktop):
-		GenericProgramMatch.__init__(self, backend, desktop, True)
+	def __init__(self, backend, use_arg=True, **args):
+		GenericProgramMatch.__init__(self, backend, use_arg=use_arg, **args)
 		self._args = ["--start", "--path", expanduser("~"), "--named"]
 		
 	def get_verb(self):
 		return _("Search for file names like %s") % "<b>%(text)s</b>"
 
-class SpecialProgramHandler(deskbar.handler.Handler):
-	def __init__(self, desktop, icon="generic.png"):
-		deskbar.handler.Handler.__init__(self, icon)
+class SpecialProgramHandler(deskbar.Handler.Handler):
+	def __init__(self, desktop, icon=gtk.STOCK_EXECUTE):
+		deskbar.Handler.Handler.__init__(self, icon)
 		self._desktop = desktop
 		self._match = None
 		
 	def initialize(self):
 		result = parse_desktop_filename(self._desktop, False)
 		if result != None:
-			self._match = self.create_match(result)
+			self._match = self.create_match(result, self._desktop)
 	
-	def create_match(self, desktop):
+	def create_match(self, desktop, f):
 		raise NotImplementedError
 		
-	def query(self, qstring, qmax=5):
+	def query(self, qstring, qmax):
 		if self._match != None:
 			return [self._match]
 		else:
@@ -108,25 +117,35 @@ class GnomeDictHandler(SpecialProgramHandler):
 	def __init__(self):
 		SpecialProgramHandler.__init__(self, "gnome-dictionary.desktop", "gdict")
 	
-	def create_match(self, desktop):
-		return GnomeDictMatch(self, desktop)
+	def create_match(self, desktop, f):
+		return GnomeDictMatch(
+					self,
+					name=cgi.escape(desktop.get_localestring(deskbar.gnomedesktop.KEY_NAME)),
+					icon=desktop.get_string(deskbar.gnomedesktop.KEY_ICON),
+					desktop=desktop,
+					desktop_file=f)
 
 class GnomeSearchHandler(SpecialProgramHandler):
 	def __init__(self):
 		SpecialProgramHandler.__init__(self, "gnome-search-tool.desktop", "gnome-searchtool")
 	
-	def create_match(self, desktop):
-		return GnomeSearchMatch(self, desktop)
+	def create_match(self, desktop, f):
+		return GnomeSearchMatch(
+					self,
+					name=cgi.escape(desktop.get_localestring(deskbar.gnomedesktop.KEY_NAME)),
+					icon=desktop.get_string(deskbar.gnomedesktop.KEY_ICON),
+					desktop=desktop,
+					desktop_file=f)
 		
-class ProgramsHandler(deskbar.handler.Handler):
+class ProgramsHandler(deskbar.Handler.Handler):
 	def __init__(self):
-		deskbar.handler.Handler.__init__(self, "generic.png")
-		self._indexer = deskbar.indexer.Index()
+		deskbar.Handler.Handler.__init__(self, gtk.STOCK_EXECUTE)
+		self._indexer = deskbar.Indexer.Indexer()
 		
 	def initialize(self):
 		self._scan_desktop_files()
 		
-	def query(self, query, max=5):
+	def query(self, query, max):
 		return self._indexer.look_up(query)[:max]
 		
 	def _scan_desktop_files(self):
@@ -134,7 +153,12 @@ class ProgramsHandler(deskbar.handler.Handler):
 			for f in glob.glob(join(dir, "applications", "*.desktop")):
 				result = parse_desktop_file(f)
 				if result != None:
-					match = GenericProgramMatch(self, result)
+					match = GenericProgramMatch(
+								self,
+								name=cgi.escape(result.get_localestring(deskbar.gnomedesktop.KEY_NAME)),
+								icon=result.get_string(deskbar.gnomedesktop.KEY_ICON),
+								desktop=result,
+								desktop_file=f)
 					self._indexer.add("%s %s %s %s %s" % (
 								result.get_string("Exec"),
 								result.get_localestring(deskbar.gnomedesktop.KEY_NAME),
@@ -144,6 +168,9 @@ class ProgramsHandler(deskbar.handler.Handler):
 							), match)
 
 def parse_desktop_filename(desktop, only_if_visible=True):
+	if desktop[0] == "/" and exists(desktop):
+		return parse_desktop_file(desktop, only_if_visible)
+			
 	for dir in get_xdg_data_dirs():
 		f = join(dir, "applications", desktop)
 		if exists(f):
