@@ -6,8 +6,8 @@ from gettext import gettext as _
 import gobject
 
 import deskbar
-from deskbar.handler import Handler
-from deskbar.handler import Match
+from deskbar.Handler import Handler
+from deskbar.Match import Match
 
 import gtk, gnome, gnomevfs
 
@@ -21,20 +21,24 @@ HANDLERS = {
 NETWORK_URIS = ["http", "ftp", "smb", "sftp"]
 AUDIO_URIS = ["cdda"]
 
+MONITOR = gnomevfs.VolumeMonitor()
+
 class VolumeMatch (Match):
-	def __init__(self, backend, drive, icon=None):
-		deskbar.handler.Match.__init__(self, backend, drive.get_display_name(), icon)
-		self.__drive = drive
+	def __init__(self, backend, name=None, drive=None, icon=None):
+		deskbar.Match.Match.__init__(self, backend, name=name, icon=icon)
+		self.drive = drive
 	
 	def action(self, text=None):
-		gobject.spawn_async(["nautilus", self.__drive.get_activation_uri()], flags=gobject.SPAWN_SEARCH_PATH)
+		gobject.spawn_async(["nautilus", self.drive], flags=gobject.SPAWN_SEARCH_PATH)
+	
+	def get_category(self):
+		return "places"
 	 
 	def get_verb(self):
-		activation = self.__drive.get_activation_uri()
-		if activation == None:
+		if self.drive == None:
 			uri_scheme = None
 		else:
-			uri_scheme = gnomevfs.get_uri_scheme(activation) 
+			uri_scheme = gnomevfs.get_uri_scheme(self.drive) 
 			
 		if uri_scheme in NETWORK_URIS:
 			return _("Open network place %s") % "<b>%(name)s</b>"
@@ -44,15 +48,15 @@ class VolumeMatch (Match):
 			return _("Open location %s") % "<b>%(name)s</b>"
 	
 	def get_hash(self, text=None):
-		return self.__drive.get_activation_uri()
+		return self.drive
 		
 class VolumeHandler (Handler):
 	
 	def __init__(self):
-		deskbar.handler.Handler.__init__(self, "gnome-dev-harddisk")
+		deskbar.Handler.Handler.__init__(self, "gnome-dev-harddisk")
 		self.__locations = []
 		
-	def query(self, query, max=5):
+	def query(self, query, max):
 		result = []
 		query = query.lower()
 		
@@ -61,12 +65,11 @@ class VolumeHandler (Handler):
 		# on "au" and "cd".
 		# Drives returned by mounted_volumes() and connected_drives()
 		# does not have the same display_name() strings.
-		for drive in gnomevfs.VolumeMonitor().get_mounted_volumes() + gnomevfs.VolumeMonitor().get_connected_drives():
+		for drive in MONITOR.get_mounted_volumes() + MONITOR.get_connected_drives():
 			if not drive.is_user_visible() : continue
 			if not drive.is_mounted () : continue
 			if not drive.get_display_name().lower().startswith(query): continue
 			
-			icon = deskbar.handler_utils.load_icon(drive.get_icon())
-			result.append (VolumeMatch (self, drive, icon))
+			result.append (VolumeMatch (self, drive.get_display_name(), drive.get_activation_uri(), drive.get_icon()))
 		
 		return result[:max]
