@@ -1,35 +1,4 @@
-#
-# Release dependant:
-#
-# - Make the pref dialog non modal ?? i tried but it doesn't work.. ?
-#
-# - (TRIVIAL) Adjust max hits per handler (especially beagle-live should return a skazillion hits)
-#
-# Would be really really nice:
-#
-# - (EASY) Show nests only for two or more nested results, or something like that
-#
-# - (MEDIUM) User defined (non-static) categories *WITHOUT PERFOMANCE HIT*
-#
-# - (?) Optimize memory and speed
-#
-# - (?) Multiscreen logic.
-#
-# - (EASY) Fine tune aligned window behavior for vertical panels
-#   Should probably check the window.gravity and construct the popup window according to that;
-#   - ie. entry at bottom, hits on top, for applets in lower half of the screen, and vice versa
-#   for applets in the top half (this can be read frm the CuemiacAlignedWindow.gravity).
-#
-#
-# Bonus features/Ideas
-#
-# - (HARD) Detach the search window to "save" the search
-#
-# - (MEDIUM) Drag hits onto desktop/nautilus to create links (likely to require additional Match api)
-#
-# - Go into shortcur mode when ctrl is pressed (with entry focus) and show flat list of avail
-#   shortcuts. When match list is focussed bind shortcuts when user hits ctrl-*. 
-#   Give visual clue like : http://raphael.slinckx.net/mocku.png
+# For TODO items previously in this file, see the TODO file in the root
 
 from os.path import *
 from gettext import gettext as _
@@ -38,12 +7,6 @@ import cgi
 import sys
 
 import gtk
-incompatible = gtk.check_version (2,8,0)
-if incompatible:
-	print _("You need Gtk+ version 2.8.0 or higher to use this module")
-	print incompatible
-	sys.exit (1) # FIXME: Throw an appropriate exception instead, so we can use a gui notification
-del incompatible
 
 import gnome, gobject, gconf
 import gnome.ui, gnomeapplet
@@ -90,7 +53,7 @@ class CuemiacCategory :
 	"""
 	A class representing a root node in the cuemiac model/view.
 	"""
-	def __init__ (self, id, parent, threshold=5):
+	def __init__ (self, id, parent):
 		"""
 		name: i18n'ed name for the category
 		parent: CuemiacTreeStore in which this category belongs
@@ -103,12 +66,18 @@ class CuemiacCategory :
 		try:
 			self.__name = CATEGORIES[id]["name"]
 			self.__id = id
+			if "threshold" in CATEGORIES[id]:
+				self.__threshold = CATEGORIES[id]["threshold"]
+			else:
+				#FIXME: this needs to be a really big number..
+				self.__threshold = 100000
 		except:
 			self.__name = CATEGORIES["default"]["name"]
+			self.__threshold = CATEGORIES["default"]["threshold"]
 			self.__id = "default"
+
 			
 		self.__priority = -1
-		self.__threshold = threshold
 		self.__count = 0
 
 	def get_category_row_path (self):
@@ -161,7 +130,7 @@ class CuemiacCategory :
 		return self.__priority
 	
 	def set_priority(self, match):
-		p = match.get_handler().get_priority()
+		p = match.get_priority()[0]
 		if self.__priority < p:
 			self.__priority = p
 			
@@ -227,11 +196,11 @@ class CuemiacModel (gtk.TreeStore):
 		text1, match1 = match1
 		text2, match2 = match2
 		
-		diff = match1.get_handler().get_priority() - match2.get_handler().get_priority()
+		diff = match1.get_priority()[0] - match2.get_priority()[0]
 		if diff != 0:
 			return diff
 			
-		diff = match1.get_priority() - match2.get_priority()
+		diff = match1.get_priority()[1] - match2.get_priority()[1]
 		if diff != 0:
 			return diff
 		
@@ -337,6 +306,9 @@ class CuemiacModel (gtk.TreeStore):
 		
 	def paths_equal (self, path1, path2):
 		"""Returns true if the two paths point to the same cell."""
+		if path1 == None or path2 == None:
+			return False
+			
 		return ( self.get_string_from_iter (self.get_iter(path1)) == self.get_string_from_iter (self.get_iter(path2)) )
 
 class CellRendererCuemiacCategory (gtk.CellRendererText):
@@ -453,8 +425,7 @@ class CuemiacTreeView (gtk.TreeView):
 		
 		self.connect ("cursor-changed", self.__on_cursor_changed)
 		self.set_property ("headers-visible", False)
-		self.set_property ("hover-selection", True)
-		self.connect ("button-press-event", self.__on_click)
+		self.connect ("row-activated", self.__on_activated)
 		self.connect ("key-press-event", self.__on_key_press)
 				
 		self.set_enable_search (False)
@@ -578,11 +549,11 @@ class CuemiacTreeView (gtk.TreeView):
 		
 		cell.set_property ("markup", model[iter][model.ACTIONS])
 
-	def __on_click (self, widget, event):
+	def __on_activated (self, treeview, path, column):
 		model, iter = self.get_selection().get_selected()
 		match = model[iter][model.MATCHES]
 		self.emit ("match-selected", match)
-				
+	
 	def __on_key_press (self, widget, event):
 		# FIXME: In the future we should check for ctrl being pressed to create shortcuts
 		model, iter = self.get_selection().get_selected()
@@ -599,7 +570,7 @@ class CuemiacTreeView (gtk.TreeView):
 					self.expand_row (path, False)
 				return True
 			
-			self.emit ("match-selected", match)
+		return False
 		
 
 class CuemiacUI (DeskbarUI):
@@ -610,17 +581,18 @@ class CuemiacUI (DeskbarUI):
 		DeskbarUI.__init__ (self, applet, prefs)
 		
 		self.default_entry_pixbuf = deskbar.Utils.load_icon("deskbar-applet-small.png", width=-1)
+		self.clipboard = gtk.clipboard_get (selection="PRIMARY")
 		
 		self.deskbar_button = DeskbarAppletButton (applet)
 		self.deskbar_button.connect ("toggled-main", lambda x,y: self.show_entry())
 		self.deskbar_button.connect ("toggled-arrow", lambda x,y: self.show_history())
 
-		self.popup = CuemiacAlignedWindow (self.deskbar_button.button_main, applet.get_orient())
+		self.popup = CuemiacAlignedWindow (self.deskbar_button.button_main, applet)
 		self.icon_entry = deskbar.iconentry.IconEntry ()
 		self.entry = self.icon_entry.get_entry ()
 		self.entry_icon = gtk.Image ()
 		self.history = get_deskbar_history ()
-		self.history_popup = CuemiacHistoryPopup (self.history, self.deskbar_button.button_arrow, applet.get_orient ())
+		self.history_popup = CuemiacHistoryPopup (self.deskbar_button.button_arrow, applet)
 		self.model = CuemiacModel ()
 		self.cview = CuemiacTreeView (self.model)
 		self.scroll_win = gtk.ScrolledWindow ()
@@ -655,8 +627,8 @@ class CuemiacUI (DeskbarUI):
 		
 		self.screen_height = self.popup.get_screen().get_height ()
 		self.screen_width = self.popup.get_screen().get_width ()
-		self.max_window_height = int (0.6 * self.screen_height)
-		self.max_window_width = int (0.4 * self.screen_width)
+		self.max_window_height = int (0.8 * self.screen_height)
+		self.max_window_width = int (0.6 * self.screen_width)
 
 		self.box.show ()
 		self.icon_entry.show_all ()
@@ -672,20 +644,20 @@ class CuemiacUI (DeskbarUI):
 		self.applet.set_applet_flags(gnomeapplet.EXPAND_MINOR)
 		self.applet.set_flags(gtk.CAN_FOCUS)
 		
-	def update_entry_icon (self):
-		path, column = self.cview.get_cursor ()
+	def update_entry_icon (self, icon=None):
+		if icon == None:
+			icon = self.default_entry_pixbuf
+			path, column = self.cview.get_cursor ()
+		
+			if path != None:
+				item = self.model[self.model.get_iter(path)][self.model.MATCHES]
+				if item.__class__ != CuemiacCategory and item.__class__ != Nest:
+					text, match = item
+					icon=match.get_icon()
+				
+		self.entry_icon.set_property('pixbuf', icon)
+		self.entry_icon.set_size_request(deskbar.ICON_WIDTH, deskbar.ICON_HEIGHT)
 		
-		if path is None:
-			self.entry_icon.set_property('pixbuf', self.default_entry_pixbuf)
-			
-		else:
-			item = self.model[self.model.get_iter(path)][self.model.MATCHES]
-			if item.__class__ == CuemiacCategory or item.__class__ == Nest:
-				self.entry_icon.set_property('pixbuf', self.default_entry_pixbuf)
-			else:
-				text, match = item
-				self.entry_icon.set_property('pixbuf', match.get_icon())
-	
 	def on_match_selected (self, cview, match, is_historic=False):
 		if match.__class__ == Nest or match.__class__ == CuemiacCategory:
 			return
@@ -695,46 +667,45 @@ class CuemiacUI (DeskbarUI):
 		else:
 			self.deskbar_button.button_main.set_active (False)
 	
-	def show_entry (self):
+	def show_entry (self, time=None):
 		if self.deskbar_button.get_active_main ():
-			#if self.entry.get_text().strip() == "":
-			self.entry.set_text("")
-			self.model.clear ()
-			self.scroll_win.hide ()
+			# Unselect what we have in the entry, so we don't occupy the middle-click-clipboard
+			# thus clearing the model on popup
+			self.entry.select_region (0,0)
+		
+			# If the entry is empty or there's something in the middle-click-clipboard
+			# clear the popup so that we can paste into the entry.
+			if self.entry.get_text().strip() == "" or self.clipboard.wait_for_text():
+				self.entry.set_text("")
+				self.model.clear ()
+				self.scroll_win.hide ()
+				
 			self.deskbar_button.button_arrow.set_active (False)
 			self.adjust_popup_size ()
-			self.popup.update_position ()
-			self.popup.show ()
-			self.entry.grab_focus ()
-			
-			#fevent = gtk.gdk.Event(gtk.gdk.FOCUS_CHANGE)
-
-			#self.entry.set_flags(gtk.HAS_FOCUS)
-			#fevent.window = self.entry.window
-			#fevent.in_ = True
-
-			#self.entry.event(fevent)
-			#self.entry.notify("has-focus")
-			#self.entry.grab_focus ()
+			# self.popup.update_position ()
 			self.update_entry_icon ()
 			
-		else:
-			#fevent = gtk.gdk.Event(gtk.gdk.FOCUS_CHANGE)
-
-			#self.entry.unset_flags(gtk.HAS_FOCUS)
-			#fevent.window = self.entry.window
-			#fevent.in_ = False
-
-			#self.entry.event(fevent)
-			#self.entry.notify("has-focus")
+			if time != None:
+				self.popup.present_with_time (time)
+			else:
+				self.popup.present ()
 			
+			self.entry.grab_focus ()
+		else:
 			self.popup.hide ()
 			self.emit ("stop-query")
 	
+	def receive_focus (self, time):
+		# Toggle expandedness of the popup
+		self.deskbar_button.button_main.set_active(not self.deskbar_button.button_main.get_active())
+		# This will focus the entry since we are passing the real event time and not the toggling time
+		if self.deskbar_button.button_main.get_active():
+			self.show_entry(time)
+		
 	def show_history (self):
 		if self.deskbar_button.get_active_arrow ():
 			self.deskbar_button.button_main.set_active (False)
-			self.history_popup.update_position ()
+			# self.history_popup.update_position ()
 			self.history_popup.show_all ()
 		else:
 			self.history_popup.hide ()
@@ -749,7 +720,6 @@ class CuemiacUI (DeskbarUI):
 		
 	def on_change_orient (self, applet):
 		self.set_layout_by_orientation (applet.get_orient())
-		print "CuemiacUI changing orientation to", applet.get_orient()
 	
 	def on_change_size (self, applet):
 		# FIXME: This is ugly, but i don't know how to get it right
@@ -772,22 +742,26 @@ class CuemiacUI (DeskbarUI):
 		if self.invalid :
 			self.invalid = False
 			self.model.clear()
-		self.model.append (matches)
+			
+		entry_text = self.entry.get_text().strip()
+		#valid_matches = False
+		#for text, match in matches:
+		#	if text == entry_text: # FIXME: Maybe it will suffice to only check the first match
+		#		self.model.append ((text,match))
+		#		valid_matches = True
+		#if valid_matches:
+		#	self.popup.show_all ()
+		for text, match in matches:
+			self.model.append ((text, match))
 		self.popup.show_all ()
-	
+		
 	def middle_click(self):
-		def clipboard_text_received(clipboard, text, data):
+		text = self.clipboard.wait_for_text ()
+		if text != None:
 			self.deskbar_button.button_main.set_active (True)
 			self.entry.grab_focus()
-			if text != None:
-				self.entry.set_text(text)
-		gtk.clipboard_get(gtk.gdk.SELECTION_PRIMARY).request_text(clipboard_text_received)
+			self.entry.set_text(text)
 		
-	def recieve_focus (self):
-		# Toggle expandedness of the popup
-		self.deskbar_button.button_main.set_active (not self.deskbar_button.button_main.get_active())
-		self.icon_entry.grab_focus ()
-
 	def set_layout_by_orientation (self, orient, reshow=True, setup=False):
 		"""orient should be a gnomeapplet.ORIENT_{UP,DOWN,LEFT,RIGHT}.
 		reshow indicates whether or not the widget should call show() on all
@@ -831,8 +805,6 @@ class CuemiacUI (DeskbarUI):
 		w = min (w, self.max_window_width)
 		if w > 0 and h > 0:
 			self.popup.resize (w, h)
-		else:
-			print "Deskbar Warning: tried to set window size to (%s, %s)" % (w, h)
 		
 	def on_entry_changed (self, entry):
 		self.history.reset()
@@ -841,6 +813,7 @@ class CuemiacUI (DeskbarUI):
 		if qstring == "":
 			self.model.clear()
 			self.scroll_win.hide ()
+			self.emit ("stop-query")
 			return
 		
 		self.invalid = True
@@ -861,7 +834,6 @@ class CuemiacUI (DeskbarUI):
 				# If we clear some text, tell async handlers to stop.
 				self.emit ("stop-query")
 			
-			self.entry.set_text("")
 			self.deskbar_button.set_active_main (False)
 			return True
 		
@@ -914,8 +886,10 @@ class CuemiacUI (DeskbarUI):
 		if iter is None:
 			# No selection, select top element # FIXME do this
 			iter = self.model.get_iter_first()
-			iter = self.model.iter_next(iter)
-		#FIXME: this seems broken
+			while (not self.model.iter_has_child(iter)) or (not self.cview.row_expanded(self.model.get_path(iter))):
+				iter = self.model.iter_next(iter)
+			iter = self.model.iter_children(iter)
+
 		if iter is None:
 			return
 			
@@ -924,9 +898,11 @@ class CuemiacUI (DeskbarUI):
 
 
 	def on_history_set(self, historymanager, set):
-		if not set:
-			#self.entry.set_text("")
-			pass
+		if set:
+			text, match = historymanager.current_history
+			self.update_entry_icon (icon=match.get_icon())
+		else:
+			self.entry.set_text("")
 			
 	def on_cview_key_press (self, cview, event):
 		# If this is an ordinary keystroke just let the
