@@ -1,18 +1,19 @@
-import gtk, pango, gobject
+import gtk, pango, gobject, gnomeapplet
 import cgi
 
 import deskbar
 from deskbar.ui.cuemiac.CuemiacAlignedWindow import CuemiacAlignedWindow
+from deskbar.DeskbarHistory import get_deskbar_history, SortedDeskbarHistory
 
-class CuemaicHistoryView (gtk.TreeView):
+class CuemiacHistoryView (gtk.TreeView):
 
 	__gsignals__ = {
 		"match-selected" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_PYOBJECT]),
 	}
 	
-	def __init__ (self, deskbar_history):
-		gtk.TreeView.__init__ (self, deskbar_history)
-		
+	def __init__ (self):
+		gtk.TreeView.__init__ (self, SortedDeskbarHistory())
+				
 		icon = gtk.CellRendererPixbuf ()
 		title = gtk.CellRendererText ()
 		title.set_property ("ellipsize", pango.ELLIPSIZE_END)
@@ -24,10 +25,8 @@ class CuemaicHistoryView (gtk.TreeView):
 		hits.set_cell_data_func(icon, self.__get_match_icon_for_cell)
 		self.append_column (hits)
 		
-		self.connect ("button-press-event", self.__on_click)
-		self.connect ("key-press-event", self.__on_key_press)
+		self.connect ("row-activated", self.__on_activated)
 		
-		self.set_property ("hover-selection", True)
 		self.set_property ("headers-visible", False)
 		
 	def __get_match_icon_for_cell (self, column, cell, model, iter, data=None):
@@ -48,20 +47,10 @@ class CuemaicHistoryView (gtk.TreeView):
 		
 		cell.set_property ("markup", match.get_verb () % verbs)
 
-	def __on_click (self, widget, event):
+	def __on_activated (self, treeview, path, column):
 		model, iter = self.get_selection().get_selected()
 		match = model[iter][0]
 		self.emit ("match-selected", match)
-				
-	def __on_key_press (self, widget, event):
-		model, iter = self.get_selection().get_selected()
-		if iter is None:
-			return False
-		match = model[iter][0]
-		if event.keyval == 65293: # enter
-			self.emit ("match-selected", match)
-			return True
-		
 
 class CuemiacHistoryPopup (CuemiacAlignedWindow) :
 
@@ -69,27 +58,36 @@ class CuemiacHistoryPopup (CuemiacAlignedWindow) :
 		"match-selected" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_PYOBJECT]),
 	}
 	
-	def __init__ (self, deskbar_history, widget_to_align_with, applet):
+	def __init__ (self, widget_to_align_with, applet):
 		CuemiacAlignedWindow.__init__ (self, widget_to_align_with, applet)
-		view = CuemaicHistoryView (deskbar_history)
-		self.add (view)
+		self.applet = applet
+		self.list_view = CuemiacHistoryView ()
+		self.add (self.list_view)
 		
-		view.connect ("match-selected", self.on_match_selected)
-		view.connect ("key-press-event", self.on_view_key_press)
+		self.list_view.connect ("match-selected", self.on_match_selected)
 	
-	def show (self):
+	def show (self, time=None):
+		if len(self.list_view.get_model()) <= 0:
+			return
+		
+		# Adapt the history popup direction to the applet orient
+		if self.applet.get_orient() in [gnomeapplet.ORIENT_LEFT, gnomeapplet.ORIENT_RIGHT, gnomeapplet.ORIENT_DOWN]:
+			self.list_view.get_model().set_sort_order(gtk.SORT_DESCENDING)
+		else:
+			self.list_view.get_model().set_sort_order(gtk.SORT_ASCENDING)
+			
 		self.update_position ()
-		CuemiacAlignedWindow.show (self)
+		if time == None:
+			CuemiacAlignedWindow.show (self)
+		else:
+			CuemiacAlignedWindow.present_with_time (self, time)
 	
 	def show_all (self):
 		self.update_position ()
 		CuemiacAlignedWindow.show_all (self)
-		
+	
 	def on_match_selected (self, sender, match):
 		self.emit ("match-selected", match)
-
-	def on_view_key_press (self, view, event):
-		self.emit ("key-press-event", event)
 		
 if gtk.pygtk_version < (2,8,0):	
 	gobject.type_register (CuemiacHistoryView)
